**pyscipopt** can be installed with the command: `conda install --channel conda-forge pyscipopt`

[**MIPLIB**](https://miplib.zib.de/index.html) is composed of 3 parts: **Instance Sets**, **Test Scripts and Solution Information**, and **Miscellaneous Downloads**, download links can be found in [here](https://miplib.zib.de/download.html).

When an instance of **MPSModel** is created, required assets are automatically installed into the default path '_assets/miplib/_'.

